@@ -23,6 +23,15 @@ FAILEDOPERATION = 'FailedOperation'
 # 动作消息不可达。
 FAILEDOPERATION_ACTIONUNREACHABLE = 'FailedOperation.ActionUnreachable'
 
+# 广播任务正在执行。
+FAILEDOPERATION_BROADCASTTASKISRUNNING = 'FailedOperation.BroadcastTaskIsRunning'
+
+# 产品未开通视频AI分析服务
+FAILEDOPERATION_CLOUDSTORAGEAISERVICENOTENABLED = 'FailedOperation.CloudStorageAIServiceNotEnabled'
+
+# 设备已经被禁用。
+FAILEDOPERATION_DEVICEALREADYDISABLED = 'FailedOperation.DeviceAlreadyDisabled'
+
 # 设备已为目标升级版本。
 FAILEDOPERATION_DEVICEFIRMWAREISUPDATED = 'FailedOperation.DeviceFirmwareIsUpdated'
 
@@ -41,6 +50,9 @@ FAILEDOPERATION_OTHERUPDATETASKEXIST = 'FailedOperation.OtherUpdateTaskExist'
 # 产品尚未发布。
 FAILEDOPERATION_PRODUCTNOTRELEASED = 'FailedOperation.ProductNotReleased'
 
+# RRPC接口未收到设备端响应。
+FAILEDOPERATION_RRPCTIMEOUT = 'FailedOperation.RRPCTimeout'
+
 # 转发已经停止。
 FAILEDOPERATION_RULEALREADYDISABLED = 'FailedOperation.RuleAlreadyDisabled'
 
@@ -56,6 +68,9 @@ FAILEDOPERATION_TIMEOUT = 'FailedOperation.Timeout'
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# DB操作错误。
+INTERNALERROR_DBOPERATIONERROR = 'InternalError.DBOperationError'
+
 # DB操作错误。
 INTERNALERROR_DBOPERTAIONERROR = 'InternalError.DBOpertaionError'
 
@@ -128,6 +143,9 @@ INVALIDPARAMETERVALUE_DEVICENAMEINVALID = 'InvalidParameterValue.DeviceNameInval
 # 设备不存在。
 INVALIDPARAMETERVALUE_DEVICENOTEXIST = 'InvalidParameterValue.DeviceNotExist'
 
+# 使用标准蓝牙广播协议的产品，DeviceName最多不超过8个字符。
+INVALIDPARAMETERVALUE_ERRLLSYNCBROADCASTDEVICENAMELENGTHEXCEED = 'InvalidParameterValue.ErrLLSyncBroadcastDeviceNameLengthExceed'
+
 # 任务不存在。
 INVALIDPARAMETERVALUE_ERRORTASKNOTEXIST = 'InvalidParameterValue.ErrorTaskNotExist'
 
@@ -140,6 +158,15 @@ INVALIDPARAMETERVALUE_FIRMWAREALREADYEXIST = 'InvalidParameterValue.FirmwareAlre
 # 转发重定向被拒绝。
 INVALIDPARAMETERVALUE_FORWARDREDIRECTDENIED = 'InvalidParameterValue.ForwardRedirectDenied'
 
+# 拉取产品列表失败。
+INVALIDPARAMETERVALUE_GETPRODUCTSLISTERROR = 'InvalidParameterValue.GetProductsListError'
+
+# 回调 Token 格式有误
+INVALIDPARAMETERVALUE_INVALIDCALLBACKTOKEN = 'InvalidParameterValue.InvalidCallbackToken'
+
+# 回调 URL 无效或格式有误
+INVALIDPARAMETERVALUE_INVALIDCALLBACKURL = 'InvalidParameterValue.InvalidCallbackUrl'
+
 # SQL语句含有非法字符。
 INVALIDPARAMETERVALUE_INVALIDSQL = 'InvalidParameterValue.InvalidSQL'
 
@@ -170,6 +197,9 @@ INVALIDPARAMETERVALUE_MODELDEFINEEVENTPROPERROR = 'InvalidParameterValue.ModelDe
 # 物模型事件/属性 Name 错误。
 INVALIDPARAMETERVALUE_MODELDEFINEEVENTPROPNAMEERROR = 'InvalidParameterValue.ModelDefineEventPropNameError'
 
+# 物模型事件 Type 错误:lac 。
+INVALIDPARAMETERVALUE_MODELDEFINEEVENTTYPEERROR = 'InvalidParameterValue.ModelDefineEventTypeError'
+
 # 数据模板未定义。
 INVALIDPARAMETERVALUE_MODELDEFINEINVALID = 'InvalidParameterValue.ModelDefineInvalid'
 
@@ -206,6 +236,9 @@ INVALIDPARAMETERVALUE_MSGTYPEINVALID = 'InvalidParameterValue.MsgTypeInvalid'
 # 操作不支持。
 INVALIDPARAMETERVALUE_OPERATIONDENIED = 'InvalidParameterValue.OperationDenied'
 
+# 消息Payload超出限制。
+INVALIDPARAMETERVALUE_PAYLOADOVERLIMIT = 'InvalidParameterValue.PayloadOverLimit'
+
 # 创建的产品名已存在。
 INVALIDPARAMETERVALUE_PRODUCTALREADYEXIST = 'InvalidParameterValue.ProductAlreadyExist'
 
@@ -227,6 +260,9 @@ INVALIDPARAMETERVALUE_REPUBLISHTOPICFORMATERROR = 'InvalidParameterValue.Republi
 # 规则数量超过限制。
 INVALIDPARAMETERVALUE_RULENUMBERBEYONDLIMIT = 'InvalidParameterValue.RuleNumberBeyondLimit'
 
+# 二进制数据格式只可利用 * 将数据进行转发。
+INVALIDPARAMETERVALUE_SELECTKEYFROMBINARYPAYLOAD = 'InvalidParameterValue.SelectKeyFromBinaryPayload'
+
 # 开始时间晚于结束时间。
 INVALIDPARAMETERVALUE_STARTTIMELATERENDTIME = 'InvalidParameterValue.StartTimeLaterEndTime'
 
@@ -290,9 +326,15 @@ LIMITEXCEEDED_TOPICPOLICYEXCEEDLIMIT = 'LimitExceeded.TopicPolicyExceedLimit'
 # 物模型事件 Type 错误。
 MISSINGPARAMETER_MODELDEFINEEVENTTYPEERROR = 'MissingParameter.ModelDefineEventTypeError'
 
+# 资源不足。
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
 # 已有量产进行，请等待量产完成。
 RESOURCEINSUFFICIENT_BATCHPRODUCTIONISRUNNING = 'ResourceInsufficient.BatchProductionIsRunning'
 
+# 资源不存在。
+RESOURCENOTFOUND = 'ResourceNotFound'
+
 # 量产不存在。
 RESOURCENOTFOUND_BATCHPRODUCTIONNOTEXIST = 'ResourceNotFound.BatchProductionNotExist'
 
@@ -302,6 +344,9 @@ RESOURCENOTFOUND_CANNOTGETFROMURL = 'ResourceNotFound.CannotGetFromUrl'
 # 存在重复设备。
 RESOURCENOTFOUND_DEVICEDUPKEYEXIST = 'ResourceNotFound.DeviceDupKeyExist'
 
+# 设备固件信息不存在。
+RESOURCENOTFOUND_DEVICEFIRMWARENOTEXIST = 'ResourceNotFound.DeviceFirmWareNotExist'
+
 # 固件不存在。
 RESOURCENOTFOUND_DEVICEHASNOFIRMWARE = 'ResourceNotFound.DeviceHasNoFirmware'
 
@@ -311,7 +356,7 @@ RESOURCENOTFOUND_DEVICENOTBIND = 'ResourceNotFound.DeviceNotBind'
 # 设备不存在。
 RESOURCENOTFOUND_DEVICENOTEXIST = 'ResourceNotFound.DeviceNotExist'
 
-# 设备没有影子信息。
+# 设备影子未创建或是已删除。
 RESOURCENOTFOUND_DEVICESHADOWNOTEXIST = 'ResourceNotFound.DeviceShadowNotExist'
 
 # 围栏未绑定该设备。
@@ -401,6 +446,9 @@ UNAUTHORIZEDOPERATION_NOPERMISSIONTOSTUDIOINSTANCE = 'UnauthorizedOperation.NoPe
 # 产品ACL错误。
 UNAUTHORIZEDOPERATION_NOPERMISSIONTOSTUDIOPRODUCT = 'UnauthorizedOperation.NoPermissionToStudioProduct'
 
+# 您的帐号未实名认证，请登录腾讯云进行实名认证
+UNAUTHORIZEDOPERATION_NOVERIFIED = 'UnauthorizedOperation.NoVerified'
+
 # 没有权限。
 UNAUTHORIZEDOPERATION_PERMISSIONDENIED = 'UnauthorizedOperation.PermissionDenied'
 
@@ -410,12 +458,18 @@ UNAUTHORIZEDOPERATION_PRODUCTNOTSUPPORTPSK = 'UnauthorizedOperation.ProductNotSu
 # License数量不足。
 UNAUTHORIZEDOPERATION_USERLICENSEEXCEEDLIMIT = 'UnauthorizedOperation.UserLicenseExceedLimit'
 
+# 未知参数错误。
+UNKNOWNPARAMETER = 'UnknownParameter'
+
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
 # 围栏下还存在绑定的设备。
 UNSUPPORTEDOPERATION_BINDSEXISTUNDERFENCE = 'UnsupportedOperation.BindsExistUnderFence'
 
+# 存在重复的绑定关系。
+UNSUPPORTEDOPERATION_CANNOTREBINDFAMILY = 'UnsupportedOperation.CannotReBindFamily'
+
 # 创建的设备已经存在。
 UNSUPPORTEDOPERATION_DEVICEDUPKEYEXIST = 'UnsupportedOperation.DeviceDupKeyExist'
 
@@ -431,6 +485,9 @@ UNSUPPORTEDOPERATION_DEVICETYPE = 'UnsupportedOperation.DeviceType'
 # 产品下还存在未删除的设备。
 UNSUPPORTEDOPERATION_DEVICESEXISTUNDERPRODUCT = 'UnsupportedOperation.DevicesExistUnderProduct'
 
+# 该项目下存在物联使能SaaS服务。
+UNSUPPORTEDOPERATION_ENABLESAASSERVICEEXISTUNDERPROJECT = 'UnsupportedOperation.EnableSaasServiceExistUnderProject'
+
 # 网关产品下存在设备绑定了子设备。
 UNSUPPORTEDOPERATION_EXISTBINDEDDEVICESUNDERGATEWAYPRODUCT = 'UnsupportedOperation.ExistBindedDevicesUnderGatewayProduct'
 
@@ -470,6 +527,9 @@ UNSUPPORTEDOPERATION_PRODUCTEXISTUNDERPROJECT = 'UnsupportedOperation.ProductExi
 # 产品被绑定到网关产品。
 UNSUPPORTEDOPERATION_PRODUCTHASBINDEDGATEWAYPRODUCT = 'UnsupportedOperation.ProductHasBindedGateWayProduct'
 
+# 产品已被共享，请先解除共享。
+UNSUPPORTEDOPERATION_PRODUCTHASSHARED = 'UnsupportedOperation.ProductHasShared'
+
 # 存在重复项目。
 UNSUPPORTEDOPERATION_PROJECTDUPKEYEXIST = 'UnsupportedOperation.ProjectDupKeyExist'
 
@@ -482,5 +542,17 @@ UNSUPPORTEDOPERATION_STAFFPOOLDUPNAMEEXIST = 'UnsupportedOperation.StaffPoolDupN
 # LoRa频点还被节点或网关使用。
 UNSUPPORTEDOPERATION_STUDIOLORAFREQINUSED = 'UnsupportedOperation.StudioLoRaFreqInUsed'
 
+# 账户有未支付订单。
+UNSUPPORTEDOPERATION_UNPAIDORDER = 'UnsupportedOperation.UnpaidOrder'
+
 # 存在重复VPN。
 UNSUPPORTEDOPERATION_VPNDUPKEYEXIST = 'UnsupportedOperation.VPNDupKeyExist'
+
+# Video账户未创建，请检查后重新操作。
+UNSUPPORTEDOPERATION_VIDEOACCOUNTNOTEXIST = 'UnsupportedOperation.VideoAccountNotExist'
+
+# Video平台license数量不足。
+UNSUPPORTEDOPERATION_VIDEOINSUFFICIENTLICENSES = 'UnsupportedOperation.VideoInsufficientLicenses'
+
+# Video平台产品不存在。
+UNSUPPORTEDOPERATION_VIDEOPRODUCTNOTEXIST = 'UnsupportedOperation.VideoProductNotExist'
